{
  pkgs,
  userName,
  ...
}: {
  # Enable flakes for NixOS
  nix.settings.experimental-features = ["nix-command" "flakes"];

  # Utilize systemd-boot
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  # For systems with AMD graphics, this enables Vulkan on 32-bit applications
  # For 64-bit application, however, Vulkan is enabled by default
  # hardware.graphics.driSupport32Bit = true;

  # For systems with AMD graphics, enable AMDVLK
  #hardware.graphics = {
  #  extraPackages = with pkgs; [
  #    amdvlk
  #  ];
  #  extraPackages32 = with pkgs; [
  #    driversi686Linux
  #  ];
  #};

  # Disable Bluetooth
  hardware.bluetooth.enable = false;

  # Set your timezone
  time.timeZone = "America/Detroit";

  # Install packages to be installed system-wide
  environment.systemPackages = with pkgs; [
    vim
    neovim
    git
    wireguard-tools
    podman
    buildah
    podman-tui
    podman-compose
    podman-desktop
    toolbox
    bind
  ];

  # Install system-wide fonts
  fonts.packages = with pkgs; [
    noto-fonts
    noto-fonts-cjk
    noto-fonts-emoji
    liberation_ttf
  ];

  # Set the EDITOR global environment variable to neovim
  environment.variables.EDITOR = "nvim";

  # Enable OpenSSH
  services.openssh.enable = true;

  # Enable keyring
  services.gnome.gnome-keyring.enable = true;

  # Enable GnuPG
  programs.gnupg.agent = {
    enable = true;
    enableSSHSupport = true;
  };

  # Enable SUID wrappers (some programs need them)
  programs.mtr.enable = true;

  # Enable Polkit
  security.polkit.enable = true;

  # Enable power management
  powerManagement = {
    enable = true;
    powertop.enable = false; # TODO: to be enabled on laptops
    cpuFreqGovernor = "performace";
  };

  # Add username to groups "wheel" and "video" - more may be added here later
  users.users.${userName}.extraGroups = ["wheel" "video" "podman" "network"];

  # Firewall stuff not allowed in common user and network creation
  networking.firewall.enable = true; # VERY important, do not touch
  networking.firewall.allowedTCPPorts = [];
  networking.firewall.allowedUDPPorts = [53];
  networking.networkmanager.enable = true; # Linux tool for managing network connections

  # Enable Podman (OCI containers)
  virtualisation.podman = {
    enable = true;
    dockerSocket.enable = true;
    defaultNetwork.settings.dns_enabled = true;
  };

  system.stateVersion = "24.05";
}
